function [residual, g1, g2, g3] = model_dynamic(y, x, params, steady_state, it_)
%
% Status : Computes dynamic model for Dynare
%
% Inputs :
%   y         [#dynamic variables by 1] double    vector of endogenous variables in the order stored
%                                                 in M_.lead_lag_incidence; see the Manual
%   x         [nperiods by M_.exo_nbr] double     matrix of exogenous variables (in declaration order)
%                                                 for all simulation periods
%   steady_state  [M_.endo_nbr by 1] double       vector of steady state values
%   params    [M_.param_nbr by 1] double          vector of parameter values in declaration order
%   it_       scalar double                       time period for exogenous variables for which to evaluate the model
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the dynamic model equations in order of 
%                                          declaration of the equations.
%                                          Dynare may prepend auxiliary equations, see M_.aux_vars
%   g1        [M_.endo_nbr by #dynamic variables] double    Jacobian matrix of the dynamic model equations;
%                                                           rows: equations in order of declaration
%                                                           columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%   g2        [M_.endo_nbr by (#dynamic variables)^2] double   Hessian matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%   g3        [M_.endo_nbr by (#dynamic variables)^3] double   Third order derivative matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

%
% Model equations
%

residual = zeros(45, 1);
T91 = 1/params(7)*params(38)*y(15)/(1+y(6));
T117 = (params(35)*y(58)+y(24)*y(19)*params(36))^params(4);
T123 = (y(45)*y(69)*(1-params(27)))^params(5);
T150 = y(15)*1/params(7)*params(37)/(1+y(6));
T201 = y(12)^params(8);
T203 = y(55)^params(18);
T205 = y(56)^params(19);
T211 = params(8)*y(12)^(params(8)-1);
T213 = T205*T203*T211;
T238 = ((1-params(11))*y(66)*y(54))^params(6);
T252 = 1-params(26)/2*(y(34)/y(7)-1)^2;
T259 = T252-y(34)*params(26)*(y(34)/y(7)-1)/y(7);
T261 = y(60)/y(16);
T266 = y(67)/y(34)-1;
T268 = (y(67)/y(34))^2;
T290 = 1-params(28)/2*(y(51)/y(11)-1)^2;
T297 = T290-y(51)*params(28)*(y(51)/y(11)-1)/y(11);
T303 = y(70)/y(51)-1;
T305 = (y(70)/y(51))^2;
T320 = y(15)-y(1)^params(15)*params(22);
T328 = y(59)-params(22)*y(15)^params(15);
T329 = T261*params(2)*params(25)*T328;
T347 = 1+params(33)*params(34)*(y(28)*params(32)+y(37)*params(31))^(params(33)-1);
T361 = (params(14)/params(2))^(1-params(16));
T362 = (1+y(3))^params(16)*T361;
T366 = (y(15)/params(14))^((1-params(16))*params(12));
T367 = T362*T366;
T372 = (y(21)/y(2))^((1-params(16))*params(13));
T396 = params(25)/2*T320^2;
lhs =params(29)*y(14)^(-1);
rhs =y(16);
residual(1)= lhs-rhs;
lhs =(1-params(29))*y(46)^(-1)+params(2)*y(60)*y(69)*(1-params(27));
rhs =y(16)*y(49);
residual(2)= lhs-rhs;
lhs =y(16);
rhs =params(2)*y(60)*(1+y(23))/y(59);
residual(3)= lhs-rhs;
lhs =y(17);
rhs =(y(16)*y(18))^(1/params(3));
residual(4)= lhs-rhs;
lhs =params(29)*y(22)^(-1);
rhs =y(20);
residual(5)= lhs-rhs;
residual(6) = (1-params(29))*y(45)^(-1)-y(49)*y(20)+(1-params(27))*y(59)*y(69)*y(44)*x(it_, 3)*params(5)/(1+y(30))+(1-params(27))*y(69)*y(62)*params(7);
lhs =y(24)^params(3);
rhs =y(20)*y(19)+y(44)*y(19)*x(it_, 2)*params(4)*params(36)+y(19)*T91*y(13);
residual(7)= lhs-rhs;
lhs =y(22)+(1+y(6))*y(8)/y(15)+y(49)*y(45);
rhs =y(24)*y(19)+y(37)+(1-params(27))*y(49)*y(9);
residual(8)= lhs-rhs;
lhs =y(37);
rhs =x(it_, 2)*T117+y(59)*x(it_, 3)/(1+y(30))*T123;
residual(9)= lhs-rhs;
lhs =y(20)-y(44);
rhs =(1+y(30))*y(62)*params(7)/y(59);
residual(10)= lhs-rhs;
lhs =y(58);
rhs =y(59)*params(37)/(1+y(30))*y(71)+y(59)*params(38)/(1+y(30))*y(61)*y(64);
residual(11)= lhs-rhs;
lhs =y(57);
rhs =y(44)*params(4)*x(it_, 2)*params(35)+y(13)*T150;
residual(12)= lhs-rhs;
lhs =y(29)^(-1);
rhs =y(27);
residual(13)= lhs-rhs;
lhs =y(18);
rhs =params(20)*y(25)/(y(55)*y(33));
residual(14)= lhs-rhs;
lhs =y(19);
rhs =y(25)*params(19)/(y(33)*y(56));
residual(15)= lhs-rhs;
lhs =y(27)-(1+y(30))*y(32);
rhs =(1+y(30))*params(10)*y(65)/y(59);
residual(16)= lhs-rhs;
lhs =y(59)*y(32)*x(it_, 1)*params(6)*y(66)*(1-params(11))+params(10)*y(65)*(y(66)*(1-params(11))+y(68));
rhs =y(27)*y(31);
residual(17)= lhs-rhs;
lhs =y(25);
rhs =T201*T203*T205;
residual(18)= lhs-rhs;
lhs =y(36);
rhs =T213/y(33);
residual(19)= lhs-rhs;
lhs =y(29)+(1+y(6))*y(5)/y(15)+y(18)*y(55)+y(19)*y(56)+y(31)*y(54);
rhs =y(25)/y(33)+y(28)+y(12)*(1-params(11))*y(31);
residual(20)= lhs-rhs;
lhs =(1+y(30))*y(28);
rhs =y(59)*x(it_, 1)*T238;
residual(21)= lhs-rhs;
lhs =y(26);
rhs =(1-params(11))*y(4)+y(34)*T252;
residual(22)= lhs-rhs;
lhs =1;
rhs =y(31)*T259+params(2)*params(26)*y(66)*T261*T266*T268;
residual(23)= lhs-rhs;
lhs =y(50);
rhs =y(45)*params(31)+y(46)*params(30);
residual(24)= lhs-rhs;
lhs =y(50);
rhs =(1-params(27))*y(10)+y(51)*T290;
residual(25)= lhs-rhs;
lhs =1;
rhs =y(49)*T297+params(2)*params(28)*y(69)*T261*T303*T305;
residual(26)= lhs-rhs;
residual(27) = 1-params(17)+params(17)/y(33)-y(15)*params(25)*T320+y(59)*T329*y(63)/y(21);
lhs =1+y(30);
rhs =(1+y(23))*T347;
residual(28)= lhs-rhs;
lhs =params(30)*y(53);
rhs =(y(28)*params(32)+y(37)*params(31))*T347;
residual(29)= lhs-rhs;
lhs =1+y(23);
rhs =T367*T372;
residual(30)= lhs-rhs;
lhs =y(21);
rhs =y(25)*params(32);
residual(31)= lhs-rhs;
lhs =y(24)*params(31);
rhs =y(56)*params(32);
residual(32)= lhs-rhs;
lhs =y(17)*params(30);
rhs =y(55)*params(32);
residual(33)= lhs-rhs;
lhs =y(26);
rhs =y(54)*params(32);
residual(34)= lhs-rhs;
lhs =y(35);
rhs =y(22)*params(31)+y(14)*params(30)+y(29)*params(32);
residual(35)= lhs-rhs;
lhs =y(21);
rhs =y(51)+y(34)+y(35)+y(21)*T396+params(34)*(y(28)*params(32)+y(37)*params(31))^params(33);
residual(36)= lhs-rhs;
lhs =y(38);
rhs =y(30)-y(23);
residual(37)= lhs-rhs;
lhs =y(39);
rhs =(y(28)*params(32)+y(37)*params(31))/y(21);
residual(38)= lhs-rhs;
lhs =y(40);
rhs =y(28)*params(32)/y(21);
residual(39)= lhs-rhs;
lhs =y(41);
rhs =y(37)*params(31)/y(21);
residual(40)= lhs-rhs;
lhs =y(48);
rhs =y(45)*(1-params(27))*y(59)*y(69)*x(it_, 3)*1/(1+y(23));
residual(41)= lhs-rhs;
lhs =y(47);
rhs =params(31)*y(48)/y(21);
residual(42)= lhs-rhs;
lhs =y(42);
rhs =y(35)/y(21);
residual(43)= lhs-rhs;
lhs =y(43);
rhs =(y(34)+y(51))/y(21);
residual(44)= lhs-rhs;
lhs =y(52);
rhs =params(31)*(y(37)-y(48))/y(21);
residual(45)= lhs-rhs;
if nargout >= 2,
  g1 = zeros(45, 74);

  %
  % Jacobian matrix
  %

T444 = (-(params(22)*getPowerDeriv(y(1),params(15),1)));
T518 = getPowerDeriv(y(16)*y(18),1/params(3),1);
T573 = getPowerDeriv(params(35)*y(58)+y(24)*y(19)*params(36),params(4),1);
T588 = getPowerDeriv(y(21)/y(2),(1-params(16))*params(13),1);
T660 = getPowerDeriv(y(28)*params(32)+y(37)*params(31),params(33)-1,1);
T669 = getPowerDeriv(y(28)*params(32)+y(37)*params(31),params(33),1);
T719 = getPowerDeriv((1-params(11))*y(66)*y(54),params(6),1);
T758 = (-(params(26)/2*(-y(34))/(y(7)*y(7))*2*(y(34)/y(7)-1)));
T772 = (-(params(26)/2*2*(y(34)/y(7)-1)*1/y(7)));
T816 = (-(params(31)/y(21)));
T827 = getPowerDeriv(y(45)*y(69)*(1-params(27)),params(5),1);
T867 = (-(params(28)/2*(-y(51))/(y(11)*y(11))*2*(y(51)/y(11)-1)));
T881 = (-(params(28)/2*2*(y(51)/y(11)-1)*1/y(11)));
T929 = getPowerDeriv(y(55),params(18),1);
T941 = getPowerDeriv(y(56),params(19),1);
  g1(1,14)=params(29)*getPowerDeriv(y(14),(-1),1);
  g1(1,16)=(-1);
  g1(2,16)=(-y(49));
  g1(2,60)=(1-params(27))*params(2)*y(69);
  g1(2,46)=(1-params(29))*getPowerDeriv(y(46),(-1),1);
  g1(2,49)=(-y(16));
  g1(2,69)=params(2)*y(60)*(1-params(27));
  g1(3,59)=(-((-(params(2)*y(60)*(1+y(23))))/(y(59)*y(59))));
  g1(3,16)=1;
  g1(3,60)=(-(params(2)*(1+y(23))/y(59)));
  g1(3,23)=(-(params(2)*y(60)/y(59)));
  g1(4,16)=(-(y(18)*T518));
  g1(4,17)=1;
  g1(4,18)=(-(y(16)*T518));
  g1(5,20)=(-1);
  g1(5,22)=params(29)*getPowerDeriv(y(22),(-1),1);
  g1(6,59)=(1-params(27))*y(69)*y(44)*x(it_, 3)*params(5)/(1+y(30));
  g1(6,20)=(-y(49));
  g1(6,62)=(1-params(27))*y(69)*params(7);
  g1(6,30)=(1-params(27))*(-(y(59)*y(69)*y(44)*x(it_, 3)*params(5)))/((1+y(30))*(1+y(30)));
  g1(6,44)=(1-params(27))*y(59)*y(69)*x(it_, 3)*params(5)/(1+y(30));
  g1(6,45)=(1-params(29))*getPowerDeriv(y(45),(-1),1);
  g1(6,49)=(-y(20));
  g1(6,69)=(1-params(27))*y(59)*y(44)*x(it_, 3)*params(5)/(1+y(30))+(1-params(27))*y(62)*params(7);
  g1(6,74)=(1-params(27))*y(59)*y(69)*y(44)*params(5)/(1+y(30));
  g1(7,15)=(-(y(13)*y(19)*1/params(7)*params(38)/(1+y(6))));
  g1(7,19)=(-(y(20)+y(44)*x(it_, 2)*params(4)*params(36)+T91*y(13)));
  g1(7,20)=(-y(19));
  g1(7,24)=getPowerDeriv(y(24),params(3),1);
  g1(7,6)=(-(y(13)*y(19)*(-(1/params(7)*params(38)*y(15)))/((1+y(6))*(1+y(6)))));
  g1(7,44)=(-(y(19)*x(it_, 2)*params(4)*params(36)));
  g1(7,13)=(-(y(19)*T91));
  g1(7,73)=(-(y(44)*y(19)*params(4)*params(36)));
  g1(8,15)=(-((1+y(6))*y(8)))/(y(15)*y(15));
  g1(8,19)=(-y(24));
  g1(8,22)=1;
  g1(8,24)=(-y(19));
  g1(8,6)=y(8)/y(15);
  g1(8,8)=(1+y(6))/y(15);
  g1(8,37)=(-1);
  g1(8,9)=(-((1-params(27))*y(49)));
  g1(8,45)=y(49);
  g1(8,49)=y(45)-(1-params(27))*y(9);
  g1(9,59)=(-(T123*x(it_, 3)/(1+y(30))));
  g1(9,19)=(-(x(it_, 2)*y(24)*params(36)*T573));
  g1(9,24)=(-(x(it_, 2)*y(19)*params(36)*T573));
  g1(9,30)=(-(T123*(-(y(59)*x(it_, 3)))/((1+y(30))*(1+y(30)))));
  g1(9,37)=1;
  g1(9,45)=(-(y(59)*x(it_, 3)/(1+y(30))*y(69)*(1-params(27))*T827));
  g1(9,69)=(-(y(59)*x(it_, 3)/(1+y(30))*T827*(1-params(27))*y(45)));
  g1(9,58)=(-(x(it_, 2)*params(35)*T573));
  g1(9,73)=(-T117);
  g1(9,74)=(-(T123*y(59)/(1+y(30))));
  g1(10,59)=(-((-((1+y(30))*y(62)*params(7)))/(y(59)*y(59))));
  g1(10,20)=1;
  g1(10,62)=(-((1+y(30))*params(7)/y(59)));
  g1(10,30)=(-(y(62)*params(7)/y(59)));
  g1(10,44)=(-1);
  g1(11,59)=(-(y(71)*params(37)/(1+y(30))+y(64)*y(61)*params(38)/(1+y(30))));
  g1(11,61)=(-(y(59)*params(38)/(1+y(30))*y(64)));
  g1(11,64)=(-(y(59)*params(38)/(1+y(30))*y(61)));
  g1(11,30)=(-(y(71)*(-(y(59)*params(37)))/((1+y(30))*(1+y(30)))+y(64)*y(61)*(-(y(59)*params(38)))/((1+y(30))*(1+y(30)))));
  g1(11,58)=1;
  g1(11,71)=(-(y(59)*params(37)/(1+y(30))));
  g1(12,15)=(-(y(13)*1/params(7)*params(37)/(1+y(6))));
  g1(12,6)=(-(y(13)*(-(y(15)*1/params(7)*params(37)))/((1+y(6))*(1+y(6)))));
  g1(12,44)=(-(params(4)*x(it_, 2)*params(35)));
  g1(12,13)=(-T150);
  g1(12,57)=1;
  g1(12,73)=(-(y(44)*params(4)*params(35)));
  g1(13,27)=(-1);
  g1(13,29)=getPowerDeriv(y(29),(-1),1);
  g1(14,18)=1;
  g1(14,25)=(-(params(20)/(y(55)*y(33))));
  g1(14,33)=(-((-(params(20)*y(25)*y(55)))/(y(55)*y(33)*y(55)*y(33))));
  g1(14,55)=(-((-(params(20)*y(25)*y(33)))/(y(55)*y(33)*y(55)*y(33))));
  g1(15,19)=1;
  g1(15,25)=(-(params(19)/(y(33)*y(56))));
  g1(15,33)=(-((-(y(25)*params(19)*y(56)))/(y(33)*y(56)*y(33)*y(56))));
  g1(15,56)=(-((-(y(33)*y(25)*params(19)))/(y(33)*y(56)*y(33)*y(56))));
  g1(16,59)=(-((-((1+y(30))*params(10)*y(65)))/(y(59)*y(59))));
  g1(16,27)=1;
  g1(16,65)=(-((1+y(30))*params(10)/y(59)));
  g1(16,30)=(-y(32))-params(10)*y(65)/y(59);
  g1(16,32)=(-(1+y(30)));
  g1(17,59)=y(32)*x(it_, 1)*params(6)*y(66)*(1-params(11));
  g1(17,27)=(-y(31));
  g1(17,65)=params(10)*(y(66)*(1-params(11))+y(68));
  g1(17,31)=(-y(27));
  g1(17,66)=(1-params(11))*y(59)*y(32)*x(it_, 1)*params(6)+params(10)*y(65)*(1-params(11));
  g1(17,32)=(1-params(11))*y(59)*y(66)*x(it_, 1)*params(6);
  g1(17,68)=params(10)*y(65);
  g1(17,72)=(1-params(11))*y(59)*y(66)*y(32)*params(6);
  g1(18,25)=1;
  g1(18,12)=(-(T205*T203*getPowerDeriv(y(12),params(8),1)));
  g1(18,55)=(-(T205*T201*T929));
  g1(18,56)=(-(T201*T203*T941));
  g1(19,33)=(-((-T213)/(y(33)*y(33))));
  g1(19,36)=1;
  g1(19,12)=(-(T205*T203*params(8)*getPowerDeriv(y(12),params(8)-1,1)/y(33)));
  g1(19,55)=(-(T205*T211*T929/y(33)));
  g1(19,56)=(-(T203*T211*T941/y(33)));
  g1(20,15)=(-((1+y(6))*y(5)))/(y(15)*y(15));
  g1(20,18)=y(55);
  g1(20,19)=y(56);
  g1(20,25)=(-(1/y(33)));
  g1(20,5)=(1+y(6))/y(15);
  g1(20,28)=(-1);
  g1(20,29)=1;
  g1(20,6)=y(5)/y(15);
  g1(20,31)=y(54)-(1-params(11))*y(12);
  g1(20,33)=(-((-y(25))/(y(33)*y(33))));
  g1(20,12)=(-((1-params(11))*y(31)));
  g1(20,54)=y(31);
  g1(20,55)=y(18);
  g1(20,56)=y(19);
  g1(21,59)=(-(x(it_, 1)*T238));
  g1(21,28)=1+y(30);
  g1(21,30)=y(28);
  g1(21,66)=(-(y(59)*x(it_, 1)*(1-params(11))*y(54)*T719));
  g1(21,54)=(-(y(59)*x(it_, 1)*y(66)*(1-params(11))*T719));
  g1(21,72)=(-(y(59)*T238));
  g1(22,4)=(-(1-params(11)));
  g1(22,26)=1;
  g1(22,7)=(-(y(34)*T758));
  g1(22,34)=(-(T252+y(34)*T772));
  g1(23,16)=(-(params(2)*T268*T266*params(26)*y(66)*(-y(60))/(y(16)*y(16))));
  g1(23,60)=(-(params(2)*T268*T266*params(26)*y(66)*1/y(16)));
  g1(23,31)=(-T259);
  g1(23,66)=(-(params(2)*T268*T266*params(26)*T261));
  g1(23,7)=(-(y(31)*(T758-(y(7)*y(34)*params(26)*(-y(34))/(y(7)*y(7))-y(34)*params(26)*(y(34)/y(7)-1))/(y(7)*y(7)))));
  g1(23,34)=(-(y(31)*(T772-(params(26)*(y(34)/y(7)-1)+y(34)*params(26)*1/y(7))/y(7))+params(2)*(T268*params(26)*y(66)*T261*(-y(67))/(y(34)*y(34))+params(26)*y(66)*T261*T266*(-y(67))/(y(34)*y(34))*2*y(67)/y(34))));
  g1(23,67)=(-(params(2)*(T268*params(26)*y(66)*T261*1/y(34)+params(26)*y(66)*T261*T266*2*y(67)/y(34)*1/y(34))));
  g1(24,45)=(-params(31));
  g1(24,46)=(-params(30));
  g1(24,50)=1;
  g1(25,10)=(-(1-params(27)));
  g1(25,50)=1;
  g1(25,11)=(-(y(51)*T867));
  g1(25,51)=(-(T290+y(51)*T881));
  g1(26,16)=(-(params(2)*T305*T303*params(28)*y(69)*(-y(60))/(y(16)*y(16))));
  g1(26,60)=(-(params(2)*T305*T303*params(28)*y(69)*1/y(16)));
  g1(26,49)=(-T297);
  g1(26,69)=(-(params(2)*T305*T303*T261*params(28)));
  g1(26,11)=(-(y(49)*(T867-(y(11)*y(51)*params(28)*(-y(51))/(y(11)*y(11))-y(51)*params(28)*(y(51)/y(11)-1))/(y(11)*y(11)))));
  g1(26,51)=(-(y(49)*(T881-(params(28)*(y(51)/y(11)-1)+y(51)*params(28)*1/y(11))/y(11))+params(2)*(T305*params(28)*y(69)*T261*(-y(70))/(y(51)*y(51))+params(28)*y(69)*T261*T303*(-y(70))/(y(51)*y(51))*2*y(70)/y(51))));
  g1(26,70)=(-(params(2)*(T305*params(28)*y(69)*T261*1/y(51)+params(28)*y(69)*T261*T303*2*y(70)/y(51)*1/y(51))));
  g1(27,1)=(-(y(15)*params(25)*T444));
  g1(27,15)=(-(params(25)*T320+y(15)*params(25)))+y(63)*y(59)*T261*params(2)*params(25)*(-(params(22)*getPowerDeriv(y(15),params(15),1)))/y(21);
  g1(27,59)=y(63)*(T329+y(59)*T261*params(2)*params(25))/y(21);
  g1(27,16)=y(63)*y(59)*T328*params(2)*params(25)*(-y(60))/(y(16)*y(16))/y(21);
  g1(27,60)=y(63)*y(59)*T328*params(2)*params(25)*1/y(16)/y(21);
  g1(27,21)=(-(y(59)*T329*y(63)))/(y(21)*y(21));
  g1(27,63)=y(59)*T329/y(21);
  g1(27,33)=(-params(17))/(y(33)*y(33));
  g1(28,23)=(-T347);
  g1(28,28)=(-((1+y(23))*params(33)*params(34)*params(32)*T660));
  g1(28,30)=1;
  g1(28,37)=(-((1+y(23))*params(33)*params(34)*params(31)*T660));
  g1(29,28)=(-(params(32)*T347+(y(28)*params(32)+y(37)*params(31))*params(33)*params(34)*params(32)*T660));
  g1(29,37)=(-(params(31)*T347+(y(28)*params(32)+y(37)*params(31))*params(33)*params(34)*params(31)*T660));
  g1(29,53)=params(30);
  g1(30,15)=(-(T372*T362*1/params(14)*getPowerDeriv(y(15)/params(14),(1-params(16))*params(12),1)));
  g1(30,2)=(-(T367*(-y(21))/(y(2)*y(2))*T588));
  g1(30,21)=(-(T367*T588*1/y(2)));
  g1(30,3)=(-(T372*T366*T361*getPowerDeriv(1+y(3),params(16),1)));
  g1(30,23)=1;
  g1(31,21)=1;
  g1(31,25)=(-params(32));
  g1(32,24)=params(31);
  g1(32,56)=(-params(32));
  g1(33,17)=params(30);
  g1(33,55)=(-params(32));
  g1(34,26)=1;
  g1(34,54)=(-params(32));
  g1(35,14)=(-params(30));
  g1(35,22)=(-params(31));
  g1(35,29)=(-params(32));
  g1(35,35)=1;
  g1(36,1)=(-(y(21)*params(25)/2*T444*2*T320));
  g1(36,15)=(-(y(21)*params(25)/2*2*T320));
  g1(36,21)=1-T396;
  g1(36,28)=(-(params(34)*params(32)*T669));
  g1(36,34)=(-1);
  g1(36,35)=(-1);
  g1(36,37)=(-(params(34)*params(31)*T669));
  g1(36,51)=(-1);
  g1(37,23)=1;
  g1(37,30)=(-1);
  g1(37,38)=1;
  g1(38,21)=(-((-(y(28)*params(32)+y(37)*params(31)))/(y(21)*y(21))));
  g1(38,28)=(-(params(32)/y(21)));
  g1(38,37)=T816;
  g1(38,39)=1;
  g1(39,21)=(-((-(y(28)*params(32)))/(y(21)*y(21))));
  g1(39,28)=(-(params(32)/y(21)));
  g1(39,40)=1;
  g1(40,21)=(-((-(y(37)*params(31)))/(y(21)*y(21))));
  g1(40,37)=T816;
  g1(40,41)=1;
  g1(41,59)=(-(y(45)*(1-params(27))*y(69)*x(it_, 3)*1/(1+y(23))));
  g1(41,23)=(-(y(45)*(1-params(27))*y(59)*y(69)*x(it_, 3)*(-1)/((1+y(23))*(1+y(23)))));
  g1(41,45)=(-((1-params(27))*y(59)*y(69)*x(it_, 3)*1/(1+y(23))));
  g1(41,48)=1;
  g1(41,69)=(-(y(45)*(1-params(27))*y(59)*x(it_, 3)*1/(1+y(23))));
  g1(41,74)=(-(y(45)*(1-params(27))*y(59)*y(69)*1/(1+y(23))));
  g1(42,21)=(-((-(params(31)*y(48)))/(y(21)*y(21))));
  g1(42,47)=1;
  g1(42,48)=T816;
  g1(43,21)=(-((-y(35))/(y(21)*y(21))));
  g1(43,35)=(-(1/y(21)));
  g1(43,42)=1;
  g1(44,21)=(-((-(y(34)+y(51)))/(y(21)*y(21))));
  g1(44,34)=(-(1/y(21)));
  g1(44,43)=1;
  g1(44,51)=(-(1/y(21)));
  g1(45,21)=(-((-(params(31)*(y(37)-y(48))))/(y(21)*y(21))));
  g1(45,37)=T816;
  g1(45,48)=(-((-params(31))/y(21)));
  g1(45,52)=1;

if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],45,5476);
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],45,405224);
end
end
end
end
