function [residual, g1, g2, g3] = model_static(y, x, params)
%
% Status : Computes static model for Dynare
%
% Inputs : 
%   y         [M_.endo_nbr by 1] double    vector of endogenous variables in declaration order
%   x         [M_.exo_nbr by 1] double     vector of exogenous variables in declaration order
%   params    [M_.param_nbr by 1] double   vector of parameter values in declaration order
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the static model equations 
%                                          in order of declaration of the equations.
%                                          Dynare may prepend or append auxiliary equations, see M_.aux_vars
%   g1        [M_.endo_nbr by M_.endo_nbr] double    Jacobian matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%   g2        [M_.endo_nbr by (M_.endo_nbr)^2] double   Hessian matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%   g3        [M_.endo_nbr by (M_.endo_nbr)^3] double   Third derivatives matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

residual = zeros( 45, 1);

%
% Model equations
%

T85 = y(2)*1/params(7)*params(38)/(1+y(17));
T113 = (y(32)*y(36)*(1-params(27)))^params(5);
T136 = y(2)*1/params(7)*params(37)/(1+y(17));
T185 = y(41)^params(8);
T187 = y(42)^params(18);
T189 = y(43)^params(19);
T194 = params(8)*y(41)^(params(8)-1);
T196 = T189*T187*T194;
T216 = ((1-params(11))*y(18)*y(41))^params(6);
T252 = y(2)-y(2)^params(15)*params(22);
T274 = 1+params(33)*params(34)*(y(15)*params(32)+y(24)*params(31))^(params(33)-1);
T286 = (params(14)/params(2))^(1-params(16));
T287 = (1+y(10))^params(16)*T286;
T291 = (y(2)/params(14))^((1-params(16))*params(12));
T317 = params(25)/2*T252^2;
lhs =params(29)*y(1)^(-1);
rhs =y(3);
residual(1)= lhs-rhs;
lhs =(1-params(29))*y(33)^(-1)+y(3)*params(2)*y(36)*(1-params(27));
rhs =y(3)*y(36);
residual(2)= lhs-rhs;
lhs =y(3);
rhs =y(3)*params(2)*(1+y(10))/y(2);
residual(3)= lhs-rhs;
lhs =y(4);
rhs =(y(3)*y(5))^(1/params(3));
residual(4)= lhs-rhs;
lhs =params(29)*y(9)^(-1);
rhs =y(7);
residual(5)= lhs-rhs;
residual(6) = (1-params(29))*y(32)^(-1)-y(36)*y(7)+(1-params(27))*y(2)*y(36)*y(31)*x(3)*params(5)/(1+y(17))+(1-params(27))*y(36)*y(7)*params(7);
lhs =y(11)^params(3);
rhs =y(7)*y(6)+y(31)*y(6)*x(2)*params(4)*params(36)+y(6)*T85*y(44);
residual(7)= lhs-rhs;
lhs =y(9)+(1+y(17))*y(24)/y(2)+y(36)*y(32);
rhs =y(24)+y(11)*y(6)+y(32)*y(36)*(1-params(27));
residual(8)= lhs-rhs;
lhs =y(24);
rhs =x(2)*(params(35)*y(45)+y(11)*y(6)*params(36))^params(4)+y(2)*x(3)/(1+y(17))*T113;
residual(9)= lhs-rhs;
lhs =y(7)-y(31);
rhs =(1+y(17))*y(7)*params(7)/y(2);
residual(10)= lhs-rhs;
lhs =y(45);
rhs =y(45)*y(2)*params(37)/(1+y(17))+y(11)*y(6)*y(2)*params(38)/(1+y(17));
residual(11)= lhs-rhs;
lhs =y(44);
rhs =y(31)*params(4)*x(2)*params(35)+y(44)*T136;
residual(12)= lhs-rhs;
lhs =y(16)^(-1);
rhs =y(14);
residual(13)= lhs-rhs;
lhs =y(5);
rhs =params(20)*y(12)/(y(42)*y(20));
residual(14)= lhs-rhs;
lhs =y(6);
rhs =y(12)*params(19)/(y(20)*y(43));
residual(15)= lhs-rhs;
lhs =y(14)-(1+y(17))*y(19);
rhs =(1+y(17))*y(14)*params(10)/y(2);
residual(16)= lhs-rhs;
lhs =y(2)*y(19)*x(1)*params(6)*y(18)*(1-params(11))+y(14)*params(10)*(y(18)*(1-params(11))+y(23));
rhs =y(14)*y(18);
residual(17)= lhs-rhs;
lhs =y(12);
rhs =T185*T187*T189;
residual(18)= lhs-rhs;
lhs =y(23);
rhs =T196/y(20);
residual(19)= lhs-rhs;
lhs =y(16)+(1+y(17))*y(15)/y(2)+y(5)*y(42)+y(6)*y(43)+y(18)*y(41);
rhs =y(15)+y(12)/y(20)+y(18)*(1-params(11))*y(41);
residual(20)= lhs-rhs;
lhs =(1+y(17))*y(15);
rhs =y(2)*x(1)*T216;
residual(21)= lhs-rhs;
lhs =y(13);
rhs =(1-params(11))*y(13)+y(21);
residual(22)= lhs-rhs;
lhs =1;
rhs =y(18);
residual(23)= lhs-rhs;
lhs =y(37);
rhs =y(32)*params(31)+y(33)*params(30);
residual(24)= lhs-rhs;
lhs =y(37);
rhs =(1-params(27))*y(37)+y(38);
residual(25)= lhs-rhs;
lhs =1;
rhs =y(36);
residual(26)= lhs-rhs;
residual(27) = 1-params(17)+params(17)/y(20)-y(2)*params(25)*T252+y(2)*T252*params(2)*params(25)*y(8)/y(8);
lhs =1+y(17);
rhs =(1+y(10))*T274;
residual(28)= lhs-rhs;
lhs =params(30)*y(40);
rhs =(y(15)*params(32)+y(24)*params(31))*T274;
residual(29)= lhs-rhs;
lhs =1+y(10);
rhs =T287*T291;
residual(30)= lhs-rhs;
lhs =y(8);
rhs =y(12)*params(32);
residual(31)= lhs-rhs;
lhs =y(11)*params(31);
rhs =y(43)*params(32);
residual(32)= lhs-rhs;
lhs =y(4)*params(30);
rhs =y(42)*params(32);
residual(33)= lhs-rhs;
lhs =y(13);
rhs =y(41)*params(32);
residual(34)= lhs-rhs;
lhs =y(22);
rhs =y(9)*params(31)+y(1)*params(30)+y(16)*params(32);
residual(35)= lhs-rhs;
lhs =y(8);
rhs =y(38)+y(21)+y(22)+y(8)*T317+params(34)*(y(15)*params(32)+y(24)*params(31))^params(33);
residual(36)= lhs-rhs;
lhs =y(25);
rhs =y(17)-y(10);
residual(37)= lhs-rhs;
lhs =y(26);
rhs =(y(15)*params(32)+y(24)*params(31))/y(8);
residual(38)= lhs-rhs;
lhs =y(27);
rhs =y(15)*params(32)/y(8);
residual(39)= lhs-rhs;
lhs =y(28);
rhs =y(24)*params(31)/y(8);
residual(40)= lhs-rhs;
lhs =y(35);
rhs =y(32)*(1-params(27))*y(2)*y(36)*x(3)*1/(1+y(10));
residual(41)= lhs-rhs;
lhs =y(34);
rhs =params(31)*y(35)/y(8);
residual(42)= lhs-rhs;
lhs =y(29);
rhs =y(22)/y(8);
residual(43)= lhs-rhs;
lhs =y(30);
rhs =(y(21)+y(38))/y(8);
residual(44)= lhs-rhs;
lhs =y(39);
rhs =params(31)*(y(24)-y(35))/y(8);
residual(45)= lhs-rhs;
if ~isreal(residual)
  residual = real(residual)+imag(residual).^2;
end
if nargout >= 2,
  g1 = zeros(45, 45);

  %
  % Jacobian matrix
  %

T401 = 1-params(22)*getPowerDeriv(y(2),params(15),1);
T431 = getPowerDeriv(y(3)*y(5),1/params(3),1);
T443 = getPowerDeriv(params(35)*y(45)+y(11)*y(6)*params(36),params(4),1);
T518 = getPowerDeriv(y(15)*params(32)+y(24)*params(31),params(33)-1,1);
T527 = getPowerDeriv(y(15)*params(32)+y(24)*params(31),params(33),1);
T574 = getPowerDeriv((1-params(11))*y(18)*y(41),params(6),1);
T616 = (-(params(31)/y(8)));
T627 = getPowerDeriv(y(32)*y(36)*(1-params(27)),params(5),1);
T673 = getPowerDeriv(y(42),params(18),1);
T685 = getPowerDeriv(y(43),params(19),1);
  g1(1,1)=params(29)*getPowerDeriv(y(1),(-1),1);
  g1(1,3)=(-1);
  g1(2,3)=(1-params(27))*params(2)*y(36)-y(36);
  g1(2,33)=(1-params(29))*getPowerDeriv(y(33),(-1),1);
  g1(2,36)=y(3)*params(2)*(1-params(27))-y(3);
  g1(3,2)=(-((-(y(3)*params(2)*(1+y(10))))/(y(2)*y(2))));
  g1(3,3)=1-params(2)*(1+y(10))/y(2);
  g1(3,10)=(-(y(3)*params(2)/y(2)));
  g1(4,3)=(-(y(5)*T431));
  g1(4,4)=1;
  g1(4,5)=(-(y(3)*T431));
  g1(5,7)=(-1);
  g1(5,9)=params(29)*getPowerDeriv(y(9),(-1),1);
  g1(6,2)=(1-params(27))*y(36)*y(31)*x(3)*params(5)/(1+y(17));
  g1(6,7)=(-y(36))+(1-params(27))*y(36)*params(7);
  g1(6,17)=(1-params(27))*(-(y(2)*y(36)*y(31)*x(3)*params(5)))/((1+y(17))*(1+y(17)));
  g1(6,31)=(1-params(27))*y(2)*y(36)*x(3)*params(5)/(1+y(17));
  g1(6,32)=(1-params(29))*getPowerDeriv(y(32),(-1),1);
  g1(6,36)=(-y(7))+(1-params(27))*y(2)*y(31)*x(3)*params(5)/(1+y(17))+(1-params(27))*y(7)*params(7);
  g1(7,2)=(-(y(44)*y(6)*1/params(7)*params(38)/(1+y(17))));
  g1(7,6)=(-(y(7)+y(31)*x(2)*params(4)*params(36)+T85*y(44)));
  g1(7,7)=(-y(6));
  g1(7,11)=getPowerDeriv(y(11),params(3),1);
  g1(7,17)=(-(y(44)*y(6)*(-(y(2)*1/params(7)*params(38)))/((1+y(17))*(1+y(17)))));
  g1(7,31)=(-(y(6)*x(2)*params(4)*params(36)));
  g1(7,44)=(-(y(6)*T85));
  g1(8,2)=(-((1+y(17))*y(24)))/(y(2)*y(2));
  g1(8,6)=(-y(11));
  g1(8,9)=1;
  g1(8,11)=(-y(6));
  g1(8,17)=y(24)/y(2);
  g1(8,24)=(1+y(17))/y(2)-1;
  g1(8,32)=y(36)-y(36)*(1-params(27));
  g1(8,36)=y(32)-(1-params(27))*y(32);
  g1(9,2)=(-(T113*x(3)/(1+y(17))));
  g1(9,6)=(-(x(2)*y(11)*params(36)*T443));
  g1(9,11)=(-(x(2)*y(6)*params(36)*T443));
  g1(9,17)=(-(T113*(-(y(2)*x(3)))/((1+y(17))*(1+y(17)))));
  g1(9,24)=1;
  g1(9,32)=(-(y(2)*x(3)/(1+y(17))*y(36)*(1-params(27))*T627));
  g1(9,36)=(-(y(2)*x(3)/(1+y(17))*T627*(1-params(27))*y(32)));
  g1(9,45)=(-(x(2)*params(35)*T443));
  g1(10,2)=(-((-((1+y(17))*y(7)*params(7)))/(y(2)*y(2))));
  g1(10,7)=1-(1+y(17))*params(7)/y(2);
  g1(10,17)=(-(y(7)*params(7)/y(2)));
  g1(10,31)=(-1);
  g1(11,2)=(-(y(45)*params(37)/(1+y(17))+y(11)*y(6)*params(38)/(1+y(17))));
  g1(11,6)=(-(y(11)*y(2)*params(38)/(1+y(17))));
  g1(11,11)=(-(y(6)*y(2)*params(38)/(1+y(17))));
  g1(11,17)=(-(y(45)*(-(y(2)*params(37)))/((1+y(17))*(1+y(17)))+y(11)*y(6)*(-(y(2)*params(38)))/((1+y(17))*(1+y(17)))));
  g1(11,45)=1-y(2)*params(37)/(1+y(17));
  g1(12,2)=(-(y(44)*1/params(7)*params(37)/(1+y(17))));
  g1(12,17)=(-(y(44)*(-(y(2)*1/params(7)*params(37)))/((1+y(17))*(1+y(17)))));
  g1(12,31)=(-(params(4)*x(2)*params(35)));
  g1(12,44)=1-T136;
  g1(13,14)=(-1);
  g1(13,16)=getPowerDeriv(y(16),(-1),1);
  g1(14,5)=1;
  g1(14,12)=(-(params(20)/(y(42)*y(20))));
  g1(14,20)=(-((-(params(20)*y(12)*y(42)))/(y(42)*y(20)*y(42)*y(20))));
  g1(14,42)=(-((-(params(20)*y(12)*y(20)))/(y(42)*y(20)*y(42)*y(20))));
  g1(15,6)=1;
  g1(15,12)=(-(params(19)/(y(20)*y(43))));
  g1(15,20)=(-((-(y(12)*params(19)*y(43)))/(y(20)*y(43)*y(20)*y(43))));
  g1(15,43)=(-((-(y(20)*y(12)*params(19)))/(y(20)*y(43)*y(20)*y(43))));
  g1(16,2)=(-((-((1+y(17))*y(14)*params(10)))/(y(2)*y(2))));
  g1(16,14)=1-(1+y(17))*params(10)/y(2);
  g1(16,17)=(-y(19))-y(14)*params(10)/y(2);
  g1(16,19)=(-(1+y(17)));
  g1(17,2)=y(19)*x(1)*params(6)*y(18)*(1-params(11));
  g1(17,14)=params(10)*(y(18)*(1-params(11))+y(23))-y(18);
  g1(17,18)=(1-params(11))*y(2)*y(19)*x(1)*params(6)+y(14)*params(10)*(1-params(11))-y(14);
  g1(17,19)=(1-params(11))*y(2)*y(18)*x(1)*params(6);
  g1(17,23)=y(14)*params(10);
  g1(18,12)=1;
  g1(18,41)=(-(T189*T187*getPowerDeriv(y(41),params(8),1)));
  g1(18,42)=(-(T189*T185*T673));
  g1(18,43)=(-(T185*T187*T685));
  g1(19,20)=(-((-T196)/(y(20)*y(20))));
  g1(19,23)=1;
  g1(19,41)=(-(T189*T187*params(8)*getPowerDeriv(y(41),params(8)-1,1)/y(20)));
  g1(19,42)=(-(T189*T194*T673/y(20)));
  g1(19,43)=(-(T187*T194*T685/y(20)));
  g1(20,2)=(-((1+y(17))*y(15)))/(y(2)*y(2));
  g1(20,5)=y(42);
  g1(20,6)=y(43);
  g1(20,12)=(-(1/y(20)));
  g1(20,15)=(1+y(17))/y(2)-1;
  g1(20,16)=1;
  g1(20,17)=y(15)/y(2);
  g1(20,18)=y(41)-(1-params(11))*y(41);
  g1(20,20)=(-((-y(12))/(y(20)*y(20))));
  g1(20,41)=y(18)-y(18)*(1-params(11));
  g1(20,42)=y(5);
  g1(20,43)=y(6);
  g1(21,2)=(-(x(1)*T216));
  g1(21,15)=1+y(17);
  g1(21,17)=y(15);
  g1(21,18)=(-(y(2)*x(1)*(1-params(11))*y(41)*T574));
  g1(21,41)=(-(y(2)*x(1)*y(18)*(1-params(11))*T574));
  g1(22,13)=1-(1-params(11));
  g1(22,21)=(-1);
  g1(23,18)=(-1);
  g1(24,32)=(-params(31));
  g1(24,33)=(-params(30));
  g1(24,37)=1;
  g1(25,37)=1-(1-params(27));
  g1(25,38)=(-1);
  g1(26,36)=(-1);
  g1(27,2)=(-(params(25)*T252+y(2)*params(25)*T401))+y(8)*(T252*params(2)*params(25)+y(2)*params(2)*params(25)*T401)/y(8);
  g1(27,20)=(-params(17))/(y(20)*y(20));
  g1(28,10)=(-T274);
  g1(28,15)=(-((1+y(10))*params(33)*params(34)*params(32)*T518));
  g1(28,17)=1;
  g1(28,24)=(-((1+y(10))*params(33)*params(34)*params(31)*T518));
  g1(29,15)=(-(params(32)*T274+(y(15)*params(32)+y(24)*params(31))*params(33)*params(34)*params(32)*T518));
  g1(29,24)=(-(params(31)*T274+(y(15)*params(32)+y(24)*params(31))*params(33)*params(34)*params(31)*T518));
  g1(29,40)=params(30);
  g1(30,2)=(-(T287*1/params(14)*getPowerDeriv(y(2)/params(14),(1-params(16))*params(12),1)));
  g1(30,10)=1-T291*T286*getPowerDeriv(1+y(10),params(16),1);
  g1(31,8)=1;
  g1(31,12)=(-params(32));
  g1(32,11)=params(31);
  g1(32,43)=(-params(32));
  g1(33,4)=params(30);
  g1(33,42)=(-params(32));
  g1(34,13)=1;
  g1(34,41)=(-params(32));
  g1(35,1)=(-params(30));
  g1(35,9)=(-params(31));
  g1(35,16)=(-params(32));
  g1(35,22)=1;
  g1(36,2)=(-(y(8)*params(25)/2*T401*2*T252));
  g1(36,8)=1-T317;
  g1(36,15)=(-(params(34)*params(32)*T527));
  g1(36,21)=(-1);
  g1(36,22)=(-1);
  g1(36,24)=(-(params(34)*params(31)*T527));
  g1(36,38)=(-1);
  g1(37,10)=1;
  g1(37,17)=(-1);
  g1(37,25)=1;
  g1(38,8)=(-((-(y(15)*params(32)+y(24)*params(31)))/(y(8)*y(8))));
  g1(38,15)=(-(params(32)/y(8)));
  g1(38,24)=T616;
  g1(38,26)=1;
  g1(39,8)=(-((-(y(15)*params(32)))/(y(8)*y(8))));
  g1(39,15)=(-(params(32)/y(8)));
  g1(39,27)=1;
  g1(40,8)=(-((-(y(24)*params(31)))/(y(8)*y(8))));
  g1(40,24)=T616;
  g1(40,28)=1;
  g1(41,2)=(-(y(32)*(1-params(27))*y(36)*x(3)*1/(1+y(10))));
  g1(41,10)=(-(y(32)*(1-params(27))*y(2)*y(36)*x(3)*(-1)/((1+y(10))*(1+y(10)))));
  g1(41,32)=(-((1-params(27))*y(2)*y(36)*x(3)*1/(1+y(10))));
  g1(41,35)=1;
  g1(41,36)=(-(y(32)*(1-params(27))*y(2)*x(3)*1/(1+y(10))));
  g1(42,8)=(-((-(params(31)*y(35)))/(y(8)*y(8))));
  g1(42,34)=1;
  g1(42,35)=T616;
  g1(43,8)=(-((-y(22))/(y(8)*y(8))));
  g1(43,22)=(-(1/y(8)));
  g1(43,29)=1;
  g1(44,8)=(-((-(y(21)+y(38)))/(y(8)*y(8))));
  g1(44,21)=(-(1/y(8)));
  g1(44,30)=1;
  g1(44,38)=(-(1/y(8)));
  g1(45,8)=(-((-(params(31)*(y(24)-y(35))))/(y(8)*y(8))));
  g1(45,24)=T616;
  g1(45,35)=(-((-params(31))/y(8)));
  g1(45,39)=1;
  if ~isreal(g1)
    g1 = real(g1)+2*imag(g1);
  end
if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],45,2025);
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],45,91125);
end
end
end
end
